pub struct VerifiedAccountBatch<'a> { /* private fields */ }Expand description
Accounts and the state root they were authenticated against.
Only obtainable from VerifiedAccountRange, so requests built from it can always be checked
against the root the accounts came from.
Implementations
Sourceimpl<'a> VerifiedAccountBatch<'a>
impl<'a> VerifiedAccountBatch<'a>
Sourcepub const fn state_root(&self) -> B256
pub const fn state_root(&self) -> B256
State root the accounts were authenticated against.